@@ -49,7 +49,7 @@ const QList<arg_option> arguments::opts = {
 	arg_option("no-gui", NULL, no_argument, true, false,
 		"Do not start the GUI. Alternatively set environment variable XCA_NO_GUI=1 or call xca as 'xca-console' symlink."),
 	arg_option("password", "password", required_argument, false, false,
-		"Database password for unlocking the database."),
+		"Database password for unlocking the database. See below for password format options."),
 	arg_option("pem", NULL, no_argument, true, false,
 		"Print PEM representation of provided files. Prints only the public part of private keys."),
 	arg_option("print", NULL, no_argument, true, false,
@@ -57,7 +57,7 @@ const QList<arg_option> arguments::opts = {
 	arg_option("select", "id-list", required_argument, true, true,
 		"Selects all items in the comma separated id-list to be shown with 'print', 'text' or 'pem'."),
 	arg_option("sqlpass", "password", required_argument, false, false,
-		"Password to access the remote SQL server."),
+		"Password to access the remote SQL server. See below for password format options."),
 	arg_option("text", NULL, no_argument, true, false,
 		"Print the content of provided files as OpenSSL does."),
 	arg_option("verbose", NULL, no_argument, false, false,
@@ -271,7 +271,6 @@ int arguments::parse(int argc, char *argv[])
 
 arguments::arguments(int argc, char *argv[])
 {
-	need_db = false;
 	parse(argc, argv);
 }
 
