@@ -100,7 +100,7 @@ QSqlError database_model::initSqlDB()
 		if (i >= ARRAY_SIZE(schemas))
 			break;
 		foreach(QString sql, schemas[i]) {
-			sql = sql.arg(b64_blob);
+			sql.replace("_B64_BLOB_", b64_blob);
 			qDebug("EXEC[%d]: '%s'", i, CCHAR(sql));
 			if (!q.exec(sql) || q.lastError().isValid()) {
 				TransRollback();
@@ -109,7 +109,7 @@ QSqlError database_model::initSqlDB()
 		}
 	}
 
-	if (i != MAX_SCHEMAS)
+	if (i < MAX_SCHEMAS)
 		throw errorEx(QObject::tr("Failed to update the database schema to the current version"));
 
 	TransCommit();
@@ -137,8 +137,12 @@ database_model::database_model(const QString &name, const Passwd &pass)
 	enum open_result result;
 	QSqlError err;
 
+#ifndef APPSTORE_COMPLIANT
 	dbName = name;
-	dbTimer = 0;
+#else
+	(void)name;
+	dbName = "default.xdb";
+#endif
 
 	if (dbName.isEmpty())
 		dbName = get_default_db();
@@ -178,12 +182,16 @@ database_model::database_model(const QString &name, const Passwd &pass)
 	 * keys first, followed by x509[req], and crls last.
 	 * Templates don't care.
 	 */
-	models << new db_key();
+	db_key *dbkey = new db_key();
+	models << dbkey;
 	models << new db_x509req();
 	models << new db_x509();
 	models << new db_crl();
 	models << new db_temp();
 
+	if (dbkey)
+		dbkey->updateKeyEncryptionScheme();
+
 	foreach(db_base *m, models) {
 		Q_CHECK_PTR(m);
 		connect(m, SIGNAL(pkiChanged(pki_base*)),
@@ -329,17 +337,9 @@ void database_model::as_default_database(const QString &db)
 database_model::~database_model()
 {
 	QByteArray ba;
-	QString connName;
-	bool dbopen;
+	QString connName =  QSqlDatabase::database().connectionName();
 
-	{
-		/* Destroy "db" at the end of the block */
-		QSqlDatabase db = QSqlDatabase::database();
-		connName= db.connectionName();
-		dbopen = db.isOpen();
-	}
-
-	if (!dbopen) {
+	if (!QSqlDatabase::database().isOpen()) {
 		QSqlDatabase::removeDatabase(connName);
 		Settings.clear();
 		return;
