@@ -22,7 +22,6 @@ pkcs11_lib::pkcs11_lib(const QString &f)
 	CK_RV (*c_get_function_list)(CK_FUNCTION_LIST_PTR_PTR);
 	CK_RV rv;
 	file = name2File(f, &enabled);
-	p11 = NULL;
 
 	if (!enabled)
 		return;
@@ -246,7 +245,7 @@ QString pkcs11_lib_list::getPkcs11Provider() const
 
 void pkcs11_lib_list::remove_libs()
 {
-	if (libs.isEmpty() == 0)
+	if (libs.isEmpty())
 		return;
 	beginRemoveRows(QModelIndex(), 0, libs.size() -1);
 	qDeleteAll(libs);
@@ -254,6 +253,10 @@ void pkcs11_lib_list::remove_libs()
 	model_data.clear();
 	endRemoveRows();
 }
+pkcs11_lib_list::~pkcs11_lib_list()
+{
+	remove_libs();
+}
 
 bool pkcs11_lib_list::loaded() const
 {
