@@ -20,14 +20,15 @@ class pkcs11_lib : public QLibrary
 {
 	Q_OBJECT
 
-    private:
-	CK_FUNCTION_LIST *p11;
-	QString file, load_error;
-	bool enabled;
+  private:
+	CK_FUNCTION_LIST *p11{};
+	QString file, load_error{};
+	bool enabled{};
 
-    public:
-	static QString name2File(const QString &name, bool *enabled = NULL);
+  public:
+	static QString name2File(const QString &name, bool *enabled = nullptr);
 	pkcs11_lib(const QString &file);
+	pkcs11_lib() = delete;
 	~pkcs11_lib();
 
 	QList<unsigned long> getSlotList();
@@ -98,6 +99,7 @@ class pkcs11_lib_list: public QAbstractListModel
 	QList<int> model_data;
 
     public:
+	~pkcs11_lib_list();
 	pkcs11_lib *add_lib(const QString &fname);
 	void load(const QString &list);
 	slotidList getSlotList() const;
