@@ -20,39 +20,22 @@ pki_lookup Store;
 
 QRegularExpression pki_base::limitPattern;
 bool pki_base::pem_comment;
-QList<pki_base*> pki_base::allitems;
 QBrush pki_base::red, pki_base::cyan, pki_base::yellow;
 
-pki_base::pki_base(const QString &name, pki_base *p)
+pki_base::pki_base(const QString &name) : desc(name)
 {
-	desc = name;
-	parent = nullptr;
-	childItems.clear();
-	pkiType=none;
-	pkiSource=unknown;
-	allitems << this;
-	iamvisible = 1;
-	qDebug() << "NEW pki_base::count" << allitems.count();
 }
 
 pki_base::pki_base(const pki_base *p)
 {
 	desc = p->desc;
-	parent = nullptr;
-	childItems.clear();
 	pkiType = p->pkiType;
 	pkiSource = p->pkiSource;
-	allitems << this;
-	iamvisible = 1;
-	qDebug() << "COPY pki_base::count" << allitems.count();
 	p->inheritFilename(this);
 }
 
 pki_base::~pki_base(void)
 {
-	if (!allitems.removeOne(this))
-		qDebug() << "DEL" << getIntName() << "NOT FOUND";
-	qDebug() << "DEL pki_base::count" << allitems.count();
 }
 
 QString pki_base::comboText() const
@@ -269,8 +252,7 @@ int pki_base::childCount() const
 
 int pki_base::indexOf(const pki_base *child) const
 {
-	int ret = childItems.indexOf(const_cast<pki_base *>(child));
-	return ret >= 0 ? ret : 0;
+	return childItems.indexOf(const_cast<pki_base *>(child));
 }
 
 void pki_base::takeChild(pki_base *pki)
@@ -287,7 +269,10 @@ QList<pki_base*> pki_base::getChildItems() const
 
 pki_base *pki_base::takeFirst()
 {
-	return childItems.takeFirst();
+	pki_base *pki = childItems.takeFirst();
+	if (pki)
+		 pki->setParent(nullptr);
+	return pki;
 }
 
 QString pki_base::pki_source_name() const
@@ -375,7 +360,9 @@ unsigned pki_base::hash(const QByteArray &ba)
 }
 unsigned pki_base::hash() const
 {
-	return hash(i2d());
+	if (!hashcache)
+		hashcache = hash(i2d());
+	return hashcache;
 }
 
 QString pki_base::get_dump_filename(const QString &dir,
