@@ -41,6 +41,7 @@ class pki_evp: public pki_key
 		static QString md5passwd(QByteArray pass);
 		static QString sha512passwd(QByteArray pass, QString salt);
 		static QString sha512passwT(QByteArray pass, QString salt);
+		static bool validateDatabasePassword(const Passwd &passwd);
 
 		pki_evp(const QString &n = QString(), int type = EVP_PKEY_RSA);
 		pki_evp(const pki_evp *pkey);
@@ -52,12 +53,16 @@ class pki_evp: public pki_key
 		void set_evp_key(EVP_PKEY *pkey);
 		void encryptKey(const char *password = NULL);
 		void bogusEncryptKey();
+		bool updateLegacyEncryption();
 		EVP_PKEY *decryptKey() const;
+		EVP_PKEY *tryDecryptKey() const;
+		EVP_PKEY *legacyDecryptKey(QByteArray &myencKey,
+					Passwd &ownPassBuf) const;
 		EVP_PKEY *priv2pub(EVP_PKEY* key);
 		static QString removeTypeFromIntName(QString n);
 		void fromPEMbyteArray(const QByteArray &ba, const QString &name);
 		void fload(const QString &fname);
-		bool pem(BioByteArray &);
+		virtual bool pem(BioByteArray &b, const pki_export *xport);
 		EVP_PKEY *load_ssh_ed25519_privatekey(const QByteArray &ba,
 						const pass_info &p);
 		void writeDefault(const QString &dirname) const;
