@@ -15,11 +15,11 @@ class pki_x509;
 
 class encAlgo
 {
-	private:
+  private:
 	static int default_encAlgo;
-	int encAlgo_nid;
+	int encAlgo_nid { NID_undef };
 
-	public:
+  public:
 	static const QList<int> all_encAlgos;
 
 	encAlgo(int nid);
@@ -29,7 +29,10 @@ class encAlgo
 
 	QString name() const;
 	int getEncAlgoNid() const;
-
+	bool legacy() const
+	{
+		return encAlgo_nid == NID_pbe_WithSHA1And3_Key_TripleDES_CBC;
+	}
 	static void setDefault(const QString &def);
 	static const encAlgo getDefault();
 };
@@ -41,9 +44,9 @@ class pki_pkcs12: public pki_multi
 	friend class pki_evp;
 
 	protected:
-		QString alias, algorithm;
-		pki_x509 *cert;
-		pki_key *key;
+		QString alias{}, algorithm{};
+		pki_x509 *cert{};
+		pki_key *key{};
 
 	public:
 		pki_pkcs12(const QString &d, pki_x509 *acert, pki_key *akey);
