@@ -25,12 +25,9 @@ void pki_scard::init(void)
 	ownPass = ptPin;
 	pkiType = smartCard;
 	isPub = false;
-
-	card_serial = card_manufacturer = card_label = "";
-	card_model = slot_label = "";
 }
 
-pki_scard::pki_scard(const QString name)
+pki_scard::pki_scard(const QString &name)
 	:pki_key(name)
 {
 	init();
@@ -206,7 +203,6 @@ EVP_PKEY *pki_scard::load_pubkey(pkcs11 &p11, CK_OBJECT_HANDLE object) const
 		EVP_PKEY_assign_EC_KEY(pkey, ec);
 		break;
 	}
-#endif
 #ifdef EVP_PKEY_ED25519
 	case CKK_EC_EDWARDS: {
 		QByteArray ba;
@@ -227,6 +223,7 @@ EVP_PKEY *pki_scard::load_pubkey(pkcs11 &p11, CK_OBJECT_HANDLE object) const
 		pki_openssl_error();
 		break;
 	}
+#endif
 #endif
 	default:
 		throw errorEx(QString("Unsupported CKA_KEY_TYPE: %1\n").arg(keytype));
@@ -347,12 +344,12 @@ pk11_attlist pki_scard::objectAttributesNoId(EVP_PKEY *pk, bool priv) const
 		attrs << pk11_attr_ulong(CKA_KEY_TYPE, CKK_EC) <<
 			pk11_attr_data(CKA_EC_PARAMS, ba);
 		break;
-#endif
 #ifdef EVP_PKEY_ED25519
 	case EVP_PKEY_ED25519:
 		attrs << pk11_attr_ulong(CKA_KEY_TYPE, CKK_EC_EDWARDS);
 		// should it also return params, somehow?
 		break;
+#endif
 #endif
 	default:
 		throw errorEx(QString("Unknown Keytype %d")
@@ -564,11 +561,11 @@ QList<int> pki_scard::possibleHashNids()
 		case EVP_PKEY_RSA:
 			switch (mechanism) {
 			case CKM_MD5_RSA_PKCS:    nids << NID_md5; break;
+			case CKM_RIPEMD160_RSA_PKCS: nids << NID_ripemd160; break;
 			case CKM_SHA1_RSA_PKCS:   nids << NID_sha1; break;
 			case CKM_SHA256_RSA_PKCS: nids << NID_sha256; break;
 			case CKM_SHA384_RSA_PKCS: nids << NID_sha384; break;
 			case CKM_SHA512_RSA_PKCS: nids << NID_sha512; break;
-			case CKM_RIPEMD160_RSA_PKCS: nids << NID_ripemd160; break;
 			}
 			break;
 		case EVP_PKEY_DSA:
@@ -779,11 +776,6 @@ void pki_scard::initPin()
 	p11.initPin(slot);
 }
 
-int pki_scard::verify()
-{
-	return true;
-}
-
 bool pki_scard::isToken()
 {
 	return true;
