@@ -88,19 +88,14 @@ const QList<QString> pki_temp::tmpl_keys = {
 };
 
 pki_temp::pki_temp(const pki_temp *pk)
-	:pki_x509name(pk->getIntName())
+	:pki_x509name(pk->getIntName()), xname(pk->xname),  settings(pk->settings)
 {
-	pre_defined = false;
-
-	xname = pk->xname;
-	settings = pk->settings;
 }
 
 pki_temp::pki_temp(const QString &d)
 	:pki_x509name(d)
 {
 	pkiType = tmpl;
-	pre_defined = false;
 
 	foreach(QString key, tmpl_keys) {
 		settings[key] = QString();
@@ -112,7 +107,7 @@ pki_temp::pki_temp(const QString &d)
 QString pki_temp::comboText() const
 {
 	return pre_defined ? QString("[default] ") + pki_base::comboText() :
-			 pki_base::comboText();
+			pki_base::comboText();
 }
 
 QSqlError pki_temp::insertSqlData()
@@ -307,7 +302,7 @@ static QString old_eKeyUse2QString(int old)
 {
 	QStringList sl;
 
-        for (int i = 0; i < extkeyuse_nid.size(); i++) {
+	for (int i = 0; i < extkeyuse_nid.size(); i++) {
 		if (old & (1<<i)) {
 			sl << OBJ_nid2sn(extkeyuse_nid[i]);
 		}
@@ -436,7 +431,7 @@ void pki_temp::writeTemp(XFile &file) const
 void pki_temp::writeDefault(const QString &dirname) const
 {
 	XFile file(get_dump_filename(dirname, ".xca"));
-        file.open_write();
+	file.open_write();
 	writeTemp(file);
 }
 
@@ -495,7 +490,7 @@ void pki_temp::fromPEM_BIO(BIO *bio, const QString &name)
 	QByteArray ba;
 	QString msg;
 	char *nm = NULL, *header = NULL;
-        unsigned char *data = NULL;
+	unsigned char *data = NULL;
 	long len;
 
 	PEM_read_bio(bio, &nm, &header, &data, &len);
