@@ -20,10 +20,9 @@
 
 x509v3ext::x509v3ext()
 {
-	ext = nullptr;
 }
 
-x509v3ext::x509v3ext(const X509_EXTENSION *n) : ext(nullptr)
+x509v3ext::x509v3ext(const X509_EXTENSION *n)
 {
 	if (n) {
 		ext = X509_EXTENSION_dup((X509_EXTENSION *)n);
@@ -31,12 +30,12 @@ x509v3ext::x509v3ext(const X509_EXTENSION *n) : ext(nullptr)
 	}
 }
 
-x509v3ext::x509v3ext(const x509v3ext &n) : ext(nullptr)
+x509v3ext::x509v3ext(const x509v3ext &n)
 {
 	set(n.ext);
 }
 
-x509v3ext::x509v3ext(int nid, const QString &et, X509V3_CTX *ctx) : ext(nullptr)
+x509v3ext::x509v3ext(int nid, const QString &et, X509V3_CTX *ctx)
 {
 	create(nid, et, ctx);
 }
@@ -74,10 +73,15 @@ x509v3ext &x509v3ext::create(int nid, const QString &et, X509V3_CTX *ctx)
 		    nid == NID_subject_alt_name)
 		{
 			x509name xn(X509_get_subject_name(ctx->subject_cert));
-			QString cn = xn.getEntryByNid(NID_commonName);
-			if (!cn.isEmpty())
-				etext.replace(QString("DNS:copycn"),
-						QString("DNS:%1").arg(cn));
+			QStringList new_san;
+			int i, max = xn.entryCount();
+			for (i=0; i < max; i++) {
+				if (xn.nid(i) == NID_commonName)
+					new_san << QString("DNS:%1").arg(xn.getEntry(i));
+			}
+			qDebug() << "COUNT" << new_san.size() << new_san.join(",");
+			if (new_san.size() > 0)
+				etext.replace(QString("DNS:copycn"), new_san.join(","));
 		}
 		QByteArray ba = etext.toLocal8Bit();
 		ext = X509V3_EXT_conf_nid(NULL, ctx, nid, ba.data());
@@ -222,7 +226,7 @@ static const char *asn1Type2Name(int type)
 {
 #define ASN1_GEN_STR(x,y) { x,y }
 	struct {
-	        const char *strnam;
+		const char *strnam;
 		int tag;
 	} tags[] = {
 		ASN1_GEN_STR("BOOL", V_ASN1_BOOLEAN),
@@ -328,10 +332,10 @@ genName2conf(GENERAL_NAME *gen, QString tag, QString *single, QString *sect)
 				arg(p[0]).arg(p[1]).arg(p[2]).arg(p[3]);
 			return true;
 		} else if(gen->d.ip->length == 8) {
-			 *single = QString("IP:%1.%2.%3.%4/%5.%6.%7.%8").
-                                arg(p[0]).arg(p[1]).arg(p[2]).arg(p[3]).
-                                arg(p[4]).arg(p[5]).arg(p[6]).arg(p[7]);
-                        return true;
+			*single = QString("IP:%1.%2.%3.%4/%5.%6.%7.%8").
+			                    arg(p[0]).arg(p[1]).arg(p[2]).arg(p[3]).
+			                    arg(p[4]).arg(p[5]).arg(p[6]).arg(p[7]);
+			return true;
 		} else if(gen->d.ip->length == 16) {
 			*single = "IP:" + ipv6_from_binary(gen->d.ip->data);
 			return true;
@@ -478,7 +482,7 @@ bool x509v3ext::parse_ainfo(QString *single, QString *adv) const
 {
 	bool retval = true;
 	QString sect, ret;
-        QString tag = OBJ_nid2sn(nid());
+	QString tag = OBJ_nid2sn(nid());
 	QStringList sl;
 	int i;
 
@@ -628,11 +632,11 @@ static void gen_cpol_notice(QString tag, USERNOTICE *notice, QString *adv)
 		QStringList sl;
 		int i;
 		*adv += QString("organization=%1\n").
-                                arg(asn1ToQString(ref->organization, true));
+		          arg(asn1ToQString(ref->organization, true));
 		for (i = 0; i < sk_ASN1_INTEGER_num(ref->noticenos); i++) {
 			a1int num(sk_ASN1_INTEGER_value(ref->noticenos, i));
 			sl << num.toDec();
-                }
+		}
 		if (sl.size())
 			*adv += QString("noticeNumbers=%1\n").
 					arg(sl.join(", "));
@@ -657,7 +661,7 @@ static bool gen_cpol_qual_sect(QString tag, POLICYINFO *pinfo, QString *adv)
 
 	for (i = 0; i < sk_POLICYQUALINFO_num(quals); i++) {
 		POLICYQUALINFO *qualinfo = sk_POLICYQUALINFO_value(quals, i);
-                switch (OBJ_obj2nid(qualinfo->pqualid)) {
+		switch (OBJ_obj2nid(qualinfo->pqualid)) {
 		case NID_id_qt_cps:
 			polsect += QString("CPS.%1=%2\n").arg(i).
 					arg(asn1ToQString(qualinfo->d.cpsuri, true));
@@ -774,7 +778,7 @@ bool x509v3ext::parse_bitstring(QString *single, QString *adv) const
 	else if (adv)
 		*adv = QString("%1=%2\n").arg(OBJ_nid2sn(nid())).arg(ret) +*adv;
 	ASN1_BIT_STRING_free(bs);
-        return true;
+	return true;
 }
 
 bool x509v3ext::parse_sKeyId(QString *, QString *adv) const
