@@ -11,18 +11,19 @@
 #include "ui_CertDetail.h"
 #include "lib/pki_x509req.h"
 #include "lib/pki_x509.h"
+#include "XcaDetail.h"
 
 class pki_x509;
 
-class CertDetail: public QDialog, public Ui::CertDetail
+class CertDetail: public XcaDetail, public Ui::CertDetail
 {
 		Q_OBJECT
 
-		bool showConf;
-		QVariant keySqlId, issuerSqlId, thisSqlId;
-		QString conf, exts;
+		bool showConf{ false };
+		QVariant keySqlId{}, issuerSqlId{}, thisSqlId{};
+		QString conf{}, exts{};
 		QLabel *labelFromAsn1String(ASN1_STRING *s);
-		pki_key *myPubKey, *tmpPubKey;
+		pki_key *myPubKey{}, *tmpPubKey{};
 		void setCert(pki_x509 *cert);
 		void setReq(pki_x509req *req);
 
@@ -34,7 +35,7 @@ class CertDetail: public QDialog, public Ui::CertDetail
 
 	private slots:
 		void on_showExt_clicked();
-		void itemChanged(pki_base *pki);
+		void itemChanged(pki_base *pki) override;
 		void showPubKey();
 		void showIssuer();
 };
