@@ -35,6 +35,7 @@
 #include "lib/pki_scard.h"
 #include "lib/dhgen.h"
 #include "lib/load_obj.h"
+#include "lib/pki_pkcs12.h"
 
 #include "XcaDialog.h"
 #include "XcaWarning.h"
@@ -44,7 +45,8 @@
 #include "Help.h"
 #include "OidResolver.h"
 
-OidResolver *MainWindow::resolver = NULL;
+OidResolver *MainWindow::resolver;
+MainWindow *mainwin;
 
 void MainWindow::enableTokenMenu(bool enable)
 {
@@ -76,6 +78,8 @@ MainWindow::MainWindow() : QMainWindow()
 	dbindex->setMargin(6);
 
 	dn_translations_setup();
+	pki_export::init_elements();
+
 	statusBar()->addWidget(dbindex, 1);
 
 	setupUi(this);
@@ -89,7 +93,6 @@ MainWindow::MainWindow() : QMainWindow()
 
 	OpenDb::initDatabases();
 
-	historyMenu = NULL;
 	helpdlg = new Help();
 	init_menu();
 	setItemEnabled(false);
@@ -128,9 +131,6 @@ MainWindow::MainWindow() : QMainWindow()
 	XcaProgress::setGui(new XcaProgressGui(this));
 	xcaWarning::setGui(new xcaWarningGui());
 	PwDialogCore::setGui(new PwDialogUI());
-
-	dhgen = nullptr;
-	dhgenProgress = nullptr;
 }
 
 void MainWindow::dropEvent(QDropEvent *event)
@@ -214,7 +214,7 @@ void MainWindow::loadPem()
 	keyView->load_default(&l);
 }
 
-bool MainWindow::pastePem(QString text, bool silent)
+bool MainWindow::pastePem(const QString &text, bool silent)
 {
 	bool success = false;
 	QByteArray pemdata = text.toLatin1();
@@ -302,7 +302,7 @@ void MainWindow::initToken()
 		p11.initToken(slot, pin.constUchar(), pin.size(), label);
 	} catch (errorEx &err) {
 		XCA_ERROR(err);
-        }
+	}
 }
 
 void MainWindow::changePin(bool so)
@@ -318,7 +318,7 @@ void MainWindow::changePin(bool so)
 		p11.changePin(slot, so);
 	} catch (errorEx &err) {
 		XCA_ERROR(err);
-        }
+	}
 }
 
 void MainWindow::changeSoPin()
@@ -339,7 +339,7 @@ void MainWindow::initPin()
 		p11.initPin(slot);
 	} catch (errorEx &err) {
 		XCA_ERROR(err);
-        }
+	}
 }
 
 
@@ -409,7 +409,7 @@ void MainWindow::manageToken()
 		}
 	} catch (errorEx &err) {
 		XCA_ERROR(err);
-        }
+	}
 	delete card;
 	delete cert;
 	delete dlgi;
@@ -421,9 +421,12 @@ MainWindow::~MainWindow()
 	EVP_cleanup();
 	OBJ_cleanup();
 	delete dbindex;
+	delete searchEdit;
 	delete helpdlg;
 
 	XcaProgress::setGui(nullptr);
+	xcaWarning::setGui(nullptr);
+	PwDialogCore::setGui(nullptr);
 }
 
 void MainWindow::closeEvent(QCloseEvent *e)
@@ -600,7 +603,26 @@ enum open_result MainWindow::setup_open_database()
 		XCA_WARN(tr("The currently used default hash '%1' is insecure. Please select at least 'SHA 224' for security reasons.").arg(defdig.name()));
 		setOptions();
 	}
-
+	encAlgo encalg = encAlgo::getDefault();
+	if (encalg.legacy() && !Settings["pkcs12_keep_legacy"]) {
+		QString text(tr("The currently used PFX / PKCS#12 algorithm '%1' is insecure.")
+				.arg(encalg.name()));
+		xcaWarningBox msg(this, text);
+		msg.addButton(QMessageBox::Ok);
+        msg.addButton(QMessageBox::Ignore);
+        msg.addButton(QMessageBox::Apply, tr("Change"));
+		switch (msg.exec())
+		{
+			case QMessageBox::Ok:
+				break;
+			case QMessageBox::Ignore:
+				Settings["pkcs12_keep_legacy"] = true;
+				break;
+			case QMessageBox::Apply:
+				setOptions();
+				break;
+		}
+	}
 	keyView->setModel(Database.model<db_key>());
 	reqView->setModel(Database.model<db_x509req>());
 	certView->setModel(Database.model<db_x509>());
@@ -730,6 +752,7 @@ void MainWindow::changeEvent(QEvent *event)
 	if (event->type() == QEvent::LanguageChange) {
 		retranslateUi(this);
 		dn_translations_setup();
+		pki_export::init_elements();
 		init_menu();
 		foreach(db_base *model, Database.getModels())
 			model->updateHeaders();
