@@ -35,7 +35,7 @@ static QString defaultlang()
 }
 
 XcaApplication::XcaApplication(int &argc, char *argv[])
-	:QApplication(argc, argv), mainw(nullptr), qtTr(nullptr), xcaTr(nullptr)
+	: QApplication(argc, argv)
 {
 	QLocale lang;
 
@@ -193,10 +193,10 @@ bool XcaApplication::notify(QObject* receiver, QEvent* event)
 		return QApplication::notify(receiver, event);
 	} catch (errorEx &err) {
 		XCA_ERROR(err);
-        } catch (...) {
+	} catch (...) {
 		qWarning() << QString("Event exception: ")
 			 << receiver << event;
-        }
+	}
 	return false;
 }
 
